@@ -7,5 +7,5 @@ def example(x=1, y="hi"):
     return x, y
 
 
-example.changed.connect(lambda e: print(e.value))
+example.changed.connect(print)
 example.show(run=True)
