@@ -4,7 +4,7 @@ from magicgui import magicgui
 
 
 # Using optional will add a '----' to the combobox, which returns "None"
-@magicgui(path=dict(choices=["a", "b"]))
+@magicgui(path={"choices": ["a", "b"]})
 def f(path: Optional[str] = None):
     print(path, type(path))
 
