@@ -1,4 +1,3 @@
-import os
 import re
 import runpy
 import sys
@@ -18,8 +17,9 @@ from magicgui import type_map, use_app
         if "_build" not in f and Path(f).read_text(encoding="utf-8").startswith("-")
     ],
 )
-def test_doc_code_cells(fname, globalns=globals()):
+def test_doc_code_cells(fname):
     """Make sure that all code cells in documentation perform as expected."""
+    globalns = globals()
     text = Path(fname).read_text()
     code_cells = re.findall(r"```{code-cell}[^\n]+\n(.*?)`{3}", text, re.S)
     for cell in code_cells:
@@ -40,13 +40,17 @@ def test_doc_code_cells(fname, globalns=globals()):
 @pytest.mark.parametrize(
     "fname", [f for f in glob("examples/*.py") if "napari" not in f]
 )
-def test_examples(fname):
+def test_examples(fname, monkeypatch):
     """Make sure that all code cells in documentation perform as expected."""
-    if "table.py" in fname and os.name == "nt" and sys.version_info < (3, 8):
-        pytest.mark.skip()
-        return
+    if "values_dialog" in str(fname):
+        from magicgui.backends._qtpy.widgets import QtW  # type: ignore
+
+        try:
+            monkeypatch.setattr(QtW.QDialog, "exec", lambda s: None)
+        except AttributeError:
+            monkeypatch.setattr(QtW.QDialog, "exec_", lambda s: None)
     app = use_app()
-    app.start_timer(0, app.quit)
+    app.start_timer(50 if "table" in str(fname) else 5, app.quit)
     try:
         runpy.run_path(fname)
     except ImportError as e:
@@ -54,5 +58,30 @@ def test_examples(fname):
             pytest.skip("numpy unavailable: skipping image example")
     finally:
         if "waveform" in fname:
-            type_map._TYPE_DEFS.pop(int, None)
-            type_map._TYPE_DEFS.pop(float, None)
+            type_map._type_map._TYPE_DEFS.pop(int, None)
+            type_map._type_map._TYPE_DEFS.pop(float, None)
+
+
+@pytest.mark.skipif(sys.version_info < (3, 11), reason="requires python3.11")
+def test_setuppy():
+    """Ensure that setup.py matches pyproject deps.
+
+    (setup.py is only there for github)
+    """
+    import ast
+
+    import tomllib
+
+    setup = Path(__file__).parent.parent / "setup.py"
+    pyproject = Path(__file__).parent.parent / "pyproject.toml"
+    settxt = setup.read_text(encoding="utf-8")
+    deps = ast.literal_eval(settxt.split("install_requires=")[-1].split("]")[0] + "]")
+
+    with open(pyproject, "rb") as f:
+        data = tomllib.load(f)
+
+    projdeps = set(data["project"]["dependencies"])
+    assert projdeps == set(deps)
+
+    min_req = data["project"]["optional-dependencies"]["min-req"]
+    assert {k.replace(">=", "==") for k in projdeps} == set(min_req)
