@@ -9,6 +9,11 @@ def test_make_annotated_raises():
     with pytest.raises(TypeError):
         make_annotated(int, "not a dict")  # type: ignore
 
+    with pytest.raises(TypeError):
+        make_annotated(Annotated[int, "string"])
+
+    make_annotated(Annotated[int, (("a", 1),)])  # this is ok
+
 
 def test_make_annotated_works_with_already_annotated():
     """Test that make_annotated merges options with Annotated types."""
